<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="zh_TW">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>應用程式代理伺服器</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理類型</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 位址</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>連線埠</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>選填</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>設定完後，請在啟動器中的應用程式右鍵選單核取「使用代理伺服器」選項</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>儲 存</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無效的IP位址</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>無效的埠</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>斷開連線</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>删 除</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>儲 存</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在連線</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>斷開連線</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>確定刪除此設定？</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>有線網路 %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>無線熱點</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>無線連接 %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE 連線 %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>新增 VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN 類型</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>匯 出</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>應用程式代理伺服器</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>個人熱點</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>網路詳情</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>系統代理伺服器</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線網路</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線網路</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>飛航模式</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>有線網路介面卡</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>新增網路連線</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>無線網路介面卡</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>連線到隱藏網路</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>建立 PPPoE 連線</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN 狀態</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>建立 VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>加入 VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理伺服器類型</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>設定 URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 位址</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>連線埠</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>無線熱點</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>建立熱點</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>界面</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC 位址</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>頻段</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>主要 DNS</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子網路遮罩</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前置詞</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>飛航模式</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>打開飛行模式將關閉無線網路、個人熱點和藍牙功能</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>無效的DNS地址</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>有線網路</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>未連結</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>裝置 MAC 位址</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>複製裝置 MAC 位址</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>自訂 MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>名稱已存在</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>自動連線</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>無線熱點</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>新增設定</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>建立熱點</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP 位址</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>IP位址重複</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無效的IP位址</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>無效的子網掩碼</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>只允許一個網關</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子網路遮罩</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>IP位址重複</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無效的IP位址</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>只允許一個網關</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前置詞</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 位址</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>僅套用到相對應來源</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>方法</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子網路遮罩</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前置詞</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無效的IP位址</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>無效的子網掩碼</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>方法</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>網路詳情</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>系統代理伺服器</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>應用程式代理伺服器</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>飛航模式</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>網路詳情</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已停用</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>依網路管理器設定</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>個人熱點</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>寬頻（PPPoE）</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>服務</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>拒絕 EAP 驗證</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>拒絕 PAP 驗證</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>拒絕 CHAP 驗證</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>拒絕 MSCHAP 驗證</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>拒絕 MSCHAPv2 驗證</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>無 BSD 資料壓縮</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>無 Deflate 資料壓縮</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>無 TCP 標頭壓縮</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>無協定欄位壓縮</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>無位址╱控制壓縮</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>傳送 PPP Echo 封包</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>使用 MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128 位 MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>包含狀態的 MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>建立 PPPoE 連線</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>系統代理伺服器</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>儲 存</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理類型</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>選填</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>連線埠</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP 代理伺服器</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS 代理伺服器</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP 代理伺服器</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS 代理伺服器</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>為主機和網域忽略代理伺服器設定</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>設定 URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>安全性</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>隧道 TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>受保護 EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>僅為該用戶存儲密碼</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>存儲所有用戶密碼</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>總是詢問</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已停用</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>匿名</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>已授權</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>兩者皆是</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>第 0 版</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>第 1 版</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP 憑證</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>識別</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密碼選項</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私鑰</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 憑證</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>使用者憑證</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>匿名 ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>自動 PAC 設定</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC 檔案</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>內部驗證</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP 版本</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>私鑰</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>密碼無效</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 個人使用者</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 個人使用者</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全性</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>金鑰</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>安全性要求</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>密碼無效</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 個人使用者</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 企業版</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 個人使用者</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>共享金鑰</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>開放式系統</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全性</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>安全認證類型</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>金鑰</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN 進階設定</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>自訂閘道器埠</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>閘道器埠</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>自訂重新協商間隔</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>重新協商間隔時間</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>使用 LZO 資料壓縮</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>使用 TCP 連線</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>使用 TAP 裝置</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>自訂隧道 MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>自訂 UDP 資料報段長度</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP 資料報段長度</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>限制通道 TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>隨機遠端主機</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN 進階設定</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco（預設）</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>安全（預設）</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>弱</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>當 NAT-T 可用時（預設）</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>總是使用 NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已停用</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2（預設）</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>伺服器（預設）</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>網域</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>提供商</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>加密</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT 穿越模式</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH 群組</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>正向加密</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>本機通訊埠</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>停用死端檢測</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>啟用 IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>群組名稱</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>群組 ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>預先分享金鑰</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 算法</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2 算法</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 憑證</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>代理伺服器</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>允許 Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD 指令碼</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>使用者憑證</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私鑰</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>為金鑰密碼使用 FSID</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>證書（TLS）</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>包含密碼證書（TLS）</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>靜態金鑰</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>已儲存</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>詢問</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>選填</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>驗證類型</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 憑證</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>使用者憑證</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私鑰</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密碼選項</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>私鑰</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>自訂金鑰方向</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>金鑰方向</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>遠端 IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>本機 IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>都能用（預設）</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 位元（較安全）</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 位元（最安全）</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>拒絕 EAP 驗證</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>拒絕 PAP 驗證</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>拒絕 CHAP 驗證</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>拒絕 MSCHAP 驗證</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>拒絕 MSCHAPv2 驗證</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>無 BSD 資料壓縮</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>無 Deflate 資料壓縮</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>無 TCP 標頭壓縮</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>無協定欄位壓縮</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>無位址╱控制壓縮</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>傳送 PPP Echo 封包</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>使用 MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全性</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>包含狀態的 MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN 狀態</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>建立 VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>加入 VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>加入錯誤</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>匯入文件錯誤</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN 代理伺服器</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>選填</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理類型</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>伺服器 IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>連線埠</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>失敗時重試無限次</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA 憑證檔</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>忽略憑證警告</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>使用 TLS 主機名稱擴充元件</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN 安全</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>預設</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>加密</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC 驗證</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>已儲存</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>詢問</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>選填</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密碼選項</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT 網域</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN 代理伺服器</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>伺服器 IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>連線埠</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私鑰</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH 代理程式</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>智慧卡</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>預先分享金鑰</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 憑證</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>驗證類型</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>使用者憑證</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>請求一個內部 IP 位址</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>強制 UDP 封裝</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>使用 IP 壓縮</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>開啟自訂加密方案</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS 驗證</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>預設</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>客戶端</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>伺服器</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>主旨相符</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>遠端憑證類型</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>金鑰檔案</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>自訂金鑰方向</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>金鑰方向</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>已儲存</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>詢問</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>選填</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密碼選項</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>群組名稱</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>群組密碼</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>使用混合驗證</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA 憑證檔</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>請先插入數據線</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>有線網路介面卡</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>新增網路連線</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>選擇設定</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>無線網路介面卡</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>關閉熱點</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>如想連線無線網路，請先關閉熱點</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>連線到隱藏網路</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>無線</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>未連結</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>裝置 MAC 位址</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>自訂 MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>